#
# Configuration file for using the libIDL library in GNOME applications
#
LIBIDL_INCLUDEDIR="-I/usr/local/include/glib-1.2 -I/usr/local/include"
LIBIDL_LIBDIR="-L/usr/local/lib"
LIBIDL_LIBS="-lIDL -L/usr/local/lib -lglib"
MODULE_VERSION="libIDL-0.6.8"